@@ -90,7 +90,7 @@ The opposite operation requires to invert \(P\) and is done by pseudo-inverse in
 We need a model of the distortions brought by the lens:
 
 - **radial** distortion cause lines far from principal point to look distorted.
-- **tangential** distortion: occur when lens is not prefectly align with the \(z\) axis of the camera. 
+- **tangential** distortion: occur when lens is not prefectly align with the \(z\) axis of the camera.
 
 Many lens distortion models exist. Here, we will use the model used in [opencv](https://docs.opencv.org/3.1.0/d4/d94/tutorial_camera_calibration.html).
 
@@ -133,7 +133,7 @@ $$\left\{\begin{align}
     \left(1 + k_1 {r_u}^2 + k_2 {r_u}^4 + k_3 {r_u}^6+\cdots\right) &\approx \left(1 + k_1 {r_d}^2 + k_2 {r_d}^4 + k_3 {r_d}^6+\cdots\right)
    \end{align}\right.
     $$
-    
+
 If this approximation holds, it's much easier to get an analytical expression of \(x_u=f_{k_{1,2,3},p_{1,2}}(x_d,y_d)\) and \(y_u=f_{k_{1,2,3},p_{1,2}}(x_d,y_d)\).
 
 
@@ -234,7 +234,7 @@ class Calib():
             Returns:
                 The point in the 2D image space on which point3D is projected by calib
         """
-        assert isinstance(point3D, Point3D), "Wrong argument type '{}'. Expected {}".format(type(point3D), Point3D)
+        #assert isinstance(point3D, Point3D), "Wrong argument type '{}'. Expected {}".format(type(point3D), Point3D)
         point2D_H = self.P @ point3D.H # returns a np.ndarray object
         point2D_H[2] = point2D_H[2] * np.sign(point2D_H[2]) # correct projection of points being projected behind the camera
         point2D = Point2D(point2D_H)
@@ -304,7 +304,7 @@ class Calib():
             point2D = Point2D(self.K @ point2D.H) # to pixel coordinates
         return point2D
 
-    def crop(self, x_slice, y_slice) -> 'Calib':
+    def crop(self, x_slice: slice, y_slice: slice) -> 'Calib':
         x0 = x_slice.start
         y0 = y_slice.start
         width = x_slice.stop - x_slice.start
@@ -312,24 +312,48 @@ class Calib():
         T = np.array([[1, 0,-x0], [0, 1,-y0], [0, 0, 1]])
         return self.update(width=width, height=height, K=T@self.K)
 
-    def scale(self, output_width, output_height) -> 'Calib':
-        sx = output_width/self.width
-        sy = output_height/self.height
+    def scale(self, output_width: int=None, output_height: int=None, sx: float=None, sy: float=None) -> 'Calib':
+        """ Returns a calib corresponding to a camera that was scaled by horizontal and vertical scale
+            factors `sx` and `sy`. If `sx` and `sy` are not given, the scale factors are computed with the current
+            width and height and the given `output_width` and `output_height`.
+        """
+        sx = sx or output_width/self.width
+        sy = sy or output_height/self.height
+        width = output_width or int(self.width*sx)
+        height = output_height or int(self.height*sy)
         S = np.array([[sx, 0, 0], [0, sy, 0], [0, 0, 1]])
-        return self.update(width=output_width, height=output_height, K=S@self.K)
+        return self.update(width=width, height=height, K=S@self.K)
 
     def flip(self) -> 'Calib':
+        """ Returns a calib corresponding to a camera that was flipped horizontally.
+        """
         F = np.array([[-1, 0, self.width-1], [0, 1, 0], [0, 0, 1]])
         return self.update(K=F@self.K)
 
     def rotate(self, angle) -> 'Calib':
+        """ Returns a calib corresponding to a camera that was rotated by `angle` degrees.
+            angle (float) : Angle of rotation in degrees.
+        """
         if angle == 0:
             return self
         A, new_width, new_height = compute_rotate(self.width, self.height, angle, degrees=True)
         return self.update(K=A@self.K, width=new_width, height=new_height)
 
-    def compute_length2D(self, length3D: float, point3D: Point3D) -> np.ndarray:
+    def rot90(self, k) -> 'Calib':
+        """ Returns a calib corresponding to a camera that was rotated `k` times around it's main axis.
+            k (int) : Number of times the array is rotated by 90 degrees.
+
+            .. todo:: This method should be tested.
+        """
+        raise NotImplementedError("Method not tested")
+        R = np.array([[0, 1, 0], [-1, 0, 0], [0, 0, 1]])**k
+        transpose = k % 2
+        return self.update(K=R@self.K, width=self.height if transpose else self.width, height=self.width if transpose else self.height)
+
+    def compute_length2D(self, point3D: Point3D, length3D: float) -> np.ndarray:
         """ Returns the length in pixel of a 3D length at point3D
+
+            .. versionchanged:: 2.8.0: `length3D` and `point3D` were interverted.
         """
         assert np.isscalar(length3D), f"This function expects a scalar `length3D` argument. Received {length3D}"
         point3D_c = Point3D(np.hstack((self.R, self.T)) @ point3D.H)  # Point3D expressed in camera coordinates system
@@ -343,9 +367,30 @@ class Calib():
             Returns `True` where for points that projects in the image and `False` otherwise.
         """
         point2D = self.project_3D_to_2D(point3D)
-        cond = np.stack((point2D.x >= 0, point2D.y >= 0, point2D.x <= self.width, point2D.y <= self.height))
+        cond = np.stack((point2D.x >= 0, point2D.y >= 0, point2D.x <= self.width-1, point2D.y <= self.height-1))
         return np.all(cond, axis=0)
 
+    def dist_to_border(self, point3D: Point3D) -> np.ndarray:
+        """ Returns the distance to `Calib` object's borders in both dimensions,
+            For each point given in point3D
+        """
+        point2D = self.project_3D_to_2D(point3D)
+        distx = np.min(np.stack((self.width - point2D.x, point2D.x)), axis=0)
+        disty = np.min(np.stack((self.height - point2D.y, point2D.y)), axis=0)
+        return distx, disty
+
+    def is_behind(self, point3D: Point3D) -> np.ndarray:
+        """ Returns `True` where for points that are behind the camera and `False` otherwise.
+        """
+        n = Point3D(0,0,1) # normal to the camera plane in camera 3D coordinates system
+        point3D_c = Point3D(np.hstack((self.R, self.T)) @ point3D.H)  # point3D expressed in camera 3D coordinates system
+        return np.asarray((n.T @ point3D_c)[0] < 0)
+
+    def __str__(self):
+        return f"Calib object ({self.width}×{self.height})@({self.C.x: 1.6g},{self.C.y: 1.6g},{self.C.z: 1.6g})"
+
+
+
 def line_plane_intersection(C: Point3D, d, P: Point3D, n) -> Point3D:
     """ Finds the intersection between a line and a plane.
         Args:
