@@ -104,7 +104,7 @@ def test_compute_length():
     calib = Calib(K=K, R=R, kc=kc, T=T, width=width, height=height)
     point3D = Point3D(1400,750,0)
     margin3D = 100 #cm
-    margin2D = calib.compute_length2D(margin3D, point3D)
+    margin2D = calib.compute_length2D(point3D, margin3D)
     assert len(margin2D.shape) == 1
     assert margin2D - 107.677886 < EPS
 
